# A program to compute compressor blade geometries from multiple-circular-arc parameters with sweep and lean (v1.0)

## About

This repository contains the source code used
to generate compressor blade geometries for the
following publication (currently under minor revisions):

 [1] Piollet, E., Nyssen, F. and Batailly, A. (2019)
"Blade/casing rubbing interactions in aircraft engines:
numerical benchmark and design guidelines based on NASA
rotor 37", Journal of Sound and Vibration

This code computes the cross-section coordinates of a compressor blade
composed of multiple-circular-arc elements including variable sweep and lean. It is a translation, adaptation and extension of a 1969 Fortran IV
code provided in the following NASA report:

 [2] Crouse, J. E., Janetzke, D. C. and Schwirian, R. E. (1969).
"A computer program for composing compressor blading from simulated
circular-arc elements on conical surfaces."

This source code should be cited as follows:

 [3] Piollet, E. and Batailly, A. (2019)
"A program to compute compressor blade geometries from
multiple-circular-arc parameters with sweep and lean (v1.0) \[source code\]",
available at [hal.archives-ouvertes](https://hal.archives-ouvertes.fr)

For more details, see **docs/documentation.pdf**

## Use
A typical use would follow these steps:

 1. write multiple-circular-arc parameters for each profile in a csv file in the folder input/profiles
 2. write sweep and lean parameters in two json files in the folder input/angles with file names blade\_name\_sweep.json and blade\_name\_lean.json, where blade\_name is the desired blade name
 3. write parameters in parameters.ini: section [main] allows chosing which module should be run (depending on whether the user wants parameter smoothing or not, or has access to Salome or not for example); sections [parameter\_smoothing], [profile\_coordinates] and [blade\_cad] include parameters for the modules of the same name
 4. run main.py

## Prerequisites

 * Python 2.7
 * Salomé: the program was tested with versions 8.2.0, 8.3.0 and 8.4.0
 
## Provided files
All input and output files related to the seven blades studied in publication [1] (see above) are provided along with the program. This includes:

 * input parameters: multiple-circular-arc profile parameters in folder input/profiles, and sweep and lean parameters for all seven blades in input/sweep_lean,
 * output for all seven blades:
    * (x, y, z) coordinates of the suction side and pressure side for each stacked profile, as well as leading edges and trailing edges, in output/coordinates/blade_name,
    * CAD (Computer-Aided Design) files in STEP format in output/CAD/blade_name,
    * finite element mesh files in output/mesh/blade_name.

## License

This source code is copyright (c) 2019 Elsa Piollet and Alain Batailly under license GPLv3
